//
//  InterfaceController.m
//  ToDoWatch WatchKit Extension
//
//  Created by Andre M. Della Torre on 11/5/15.
//  Copyright © 2015 Andre M. Della Torre. All rights reserved.
//

#import "InterfaceController.h"
#import "ToDoRow.h"
#import "ToDoItem.h"
#import "ToDoController.h"

@interface InterfaceController()

@property (unsafe_unretained, nonatomic) IBOutlet WKInterfaceTable *table;

@end


@implementation InterfaceController

- (void)awakeWithContext:(id)context {
    [super awakeWithContext:context];
    // Configure interface objects here.
    
    ExtensionDelegate *extensionDelegate = (ExtensionDelegate *)[[WKExtension sharedExtension] delegate];
    [extensionDelegate setWatchCommDelegate:self];
    
    //Preenche a tabela
    [self setupTable];
}

- (void)willActivate {
    // This method is called when watch view controller is about to be visible to user
    [super willActivate];
}

- (void)didDeactivate {
    // This method is called when watch view controller is no longer visible
    [super didDeactivate];
}

-(void)table:(WKInterfaceTable *)table didSelectRowAtIndex:(NSInteger)rowIndex
{
    //Marca como Feito ou não feito (inverte o valor a cada click)
    NSDictionary *toDoItem = [[ToDoController toDoList] objectAtIndex:rowIndex];
    [ToDoController toggleToDo:[toDoItem objectForKey:TODO_ID_KEY]];
    
    //Preenche a tabela
    [self setupTable];
}

-(void)setupTable
{
    [self.table setNumberOfRows:[ToDoController toDoList].count withRowType:@"ToDoRow"];
    
    //Para cada item da lista configura a linha na tabela
    for (NSInteger idx = 0; idx < self.table.numberOfRows; idx++) {
        ToDoRow *toDoRow = [self.table rowControllerAtIndex:idx];
        
        ToDoItem *toDoItem = [[ToDoItem alloc] initWithDictionary:[[ToDoController toDoList] objectAtIndex:idx]];
        [toDoRow configRowWithItem:toDoItem];
    }
}

#pragma mark - WatchCommProtocol

-(void)contextReceived:(NSDictionary<NSString *,id> *)context
{
    NSArray *toDos = [context objectForKey:@"toDoList"];
    
    [ToDoController clearAll];
    
    for (NSInteger idx = 0; idx < toDos.count; idx++) {
        NSDictionary *toDoItem = [toDos objectAtIndex:idx];
        [ToDoController addToDoItem:toDoItem];
    }
    
    [self setupTable];
}

@end



