//
//  ToDoController.m
//  ToDoWatch
//
//  Created by Andre M. Della Torre on 1/15/16.
//  Copyright © 2016 Andre M. Della Torre. All rights reserved.
//

#import "ToDoController.h"
#import "ToDoItem.h"
#import <WatchConnectivity/WatchConnectivity.h>

@implementation ToDoController

static NSMutableArray *_toDoList;

+(NSMutableArray *) toDoList
{
    if(!_toDoList)
    {
        NSUserDefaults *defaults = [[NSUserDefaults standardUserDefaults]
                                    initWithSuiteName:TODO_SHARE_GROUP_NAME];
        _toDoList = [[defaults arrayForKey:TODO_LIST_KEY] mutableCopy];
        
        if(!_toDoList)
            _toDoList = [NSMutableArray new];
    }
    
    return _toDoList;
}

+(void)addToDoItem:(NSDictionary *)todoItem
{
    [[self toDoList] addObject:todoItem];
    [self updateToDoList];
}

+(void)toggleToDo:(NSNumber *)toDoId
{
    NSMutableArray *list= [self toDoList];
    
    NSDictionary *toDoItem = [[list filteredArrayUsingPredicate:[NSPredicate predicateWithFormat:@"toDoId = %@", toDoId]] firstObject];
    
    if(toDoItem)
    {
        NSUInteger idx = [list indexOfObject:toDoItem];
        
        [list removeObjectAtIndex:idx];
        [list insertObject:@{TODO_ID_KEY : toDoId,
                             TODO_TITLE_KEY : [toDoItem objectForKey:TODO_TITLE_KEY],
                             TODO_DONE_KEY : @(![[toDoItem objectForKey:TODO_DONE_KEY] boolValue])}
                   atIndex:idx];
        
        [self updateToDoList];
        
        [[WCSession defaultSession] transferUserInfo:@{@"toogle" : toDoId}];
    }
}

+(void)updateToDoList
{
    NSUserDefaults *defaults = [[NSUserDefaults standardUserDefaults]
                                initWithSuiteName:TODO_SHARE_GROUP_NAME];
    [defaults setObject:[self toDoList] forKey:TODO_LIST_KEY];
    [defaults synchronize];
}

+(void)clearAll
{
    _toDoList = [NSMutableArray new];
}

@end
