//
//  ToDoController.m
//  ToDoWatch
//
//  Created by Andre M. Della Torre on 1/15/16.
//  Copyright © 2016 Andre M. Della Torre. All rights reserved.
//

#import "ToDoController.h"
#import <WatchConnectivity/WatchConnectivity.h>

@implementation ToDoController

static NSMutableArray *_toDoList;

+(NSMutableArray *) toDoList
{
    //Inicializa a lista de ToDos com os item já gravados ou uma nova lista vazia.
    if(!_toDoList)
    {
        NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
        _toDoList = [[defaults arrayForKey:TODO_LIST_KEY] mutableCopy];
        
        if(!_toDoList)
            _toDoList = [NSMutableArray new];
    }
    
    return _toDoList;
}

+(void)updateToDoList
{
    //Grava a lista atual de ToDos
    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
    [defaults setObject:[self toDoList] forKey:TODO_LIST_KEY];
    [defaults synchronize];
    
    [self sendToDosToWatch];
}

+(void)createNewToDo:(NSString *)title
{
    NSNumber *toDoId;
    NSMutableArray *allToDos = [self toDoList];
    
    //Verifica se existe algum ToDo na lista e define o Id do proximo a ser inserido
    if(allToDos.count == 0)
        toDoId = @1;
    else
        toDoId = @([[allToDos valueForKeyPath:@"@max.toDoId"] integerValue] + 1);
    
    [allToDos addObject:@{TODO_ID_KEY : toDoId,
                          TODO_TITLE_KEY : title,
                          TODO_DONE_KEY : @(NO)}];
    
    [self updateToDoList];
}

+(void)deleteTodo:(NSDictionary *)toDoItem
{
    [_toDoList removeObject:toDoItem];
    [self updateToDoList];
}

+(void)toggleToDo:(NSNumber *)toDoId
{
    NSMutableArray *list= [self toDoList];
    
    NSDictionary *toDoItem = [[list filteredArrayUsingPredicate:[NSPredicate predicateWithFormat:@"toDoId = %@", toDoId]] firstObject];
    
    if(toDoItem)
    {
        NSUInteger idx = [list indexOfObject:toDoItem];
        
        [list removeObjectAtIndex:idx];
        [list insertObject:@{TODO_ID_KEY : toDoId,
                             TODO_TITLE_KEY : [toDoItem objectForKey:TODO_TITLE_KEY],
                             TODO_DONE_KEY : @(![[toDoItem objectForKey:TODO_DONE_KEY] boolValue])}
                   atIndex:idx];
        
        [self updateToDoList];
    }
}

+(void)sendToDosToWatch
{
    //Filtra os todos nao fimalizados
    NSArray *toDoUndone = [[self toDoList] filteredArrayUsingPredicate:[NSPredicate predicateWithFormat:@"done = %@", @(NO)]];
    NSDictionary *context = @{TODO_LIST_KEY : toDoUndone};
    
    //envia os todos para o relogio
    [[WCSession defaultSession] updateApplicationContext:context
                                                   error:nil];
}

@end
