//
//  InterfaceController.swift
//  ToDoWatch WatchKit Extension
//
//  Created by Andre M. Della Torre on 11/5/15.
//  Copyright © 2015 Andre M. Della Torre. All rights reserved.
//

import WatchKit
import Foundation


class InterfaceController: WKInterfaceController, WatchCommProtocol {

    @IBOutlet var table: WKInterfaceTable!
    
    
    override func awakeWithContext(context: AnyObject?) {
        super.awakeWithContext(context)

        let extensionDelegate = WKExtension.sharedExtension().delegate as! ExtensionDelegate
        extensionDelegate.watchCommDelegate = self
        
        //Preenche a tabela
        setupTable()
    }

    override func willActivate() {
        // This method is called when watch view controller is about to be visible to user
        super.willActivate()
    }

    override func didDeactivate() {
        // This method is called when watch view controller is no longer visible
        super.didDeactivate()
    }
    
    override func table(table: WKInterfaceTable, didSelectRowAtIndex rowIndex: Int) {
        
        //Marca como Feito ou não feito (inverte o valor a cada click)
        let toDoItem = ToDoController.toDoList[rowIndex]
        ToDoController.toggleToDo(toDoItem[ToDoController.TODO_ID_KEY] as! Int)
        
        //Preenche a tabela
        setupTable()
    }
    
    func setupTable() {
        
        //Seta o numero de item da lista
        table.setNumberOfRows(ToDoController.toDoList.count, withRowType: "ToDoRow")
        
        //Para cada item da lista configura a linha na tabela
        for idx in 0...table.numberOfRows {
            if let toDoRow = table.rowControllerAtIndex(idx) as? ToDoRow {
                let toDoItem = ToDoItem.init(fromDictionary: ToDoController.toDoList[idx])
                toDoRow.configRowWithItem(toDoItem)
            }
        }
    }
    
    // Mark : WatchCommProtocol
    func contextReceived(context: [String : AnyObject]) {
        let toDos = context["toDoList"] as! [[String:AnyObject]]
        
        ToDoController.clearAll()
        
        for toDo in toDos {
            ToDoController.addToDoItem(toDo)
        }
        
        setupTable()
    }
}
