//
//  ToDoController.swift
//  ToDoWatch
//
//  Created by Andre M. Della Torre on 1/14/16.
//  Copyright © 2016 Andre M. Della Torre. All rights reserved.
//

import UIKit
import WatchConnectivity

class ToDoController {

    static let TODO_LIST_KEY = "toDoList"
    static let TODO_ID_KEY = "toDoId"
    static let TODO_TITLE_KEY = "title"
    static let TODO_DONE_KEY = "done"
    
    static var toDoList = ToDoController.loadToDoList()
    
    static func loadToDoList() -> [[String:AnyObject]] {
        
        //Inicializa a lista de ToDos com os item já gravados ou uma nova lista vazia.
        let defaults = NSUserDefaults.standardUserDefaults()
        if let toDos = defaults.arrayForKey(TODO_LIST_KEY) {
            return toDos as! [[String:AnyObject]]
        }
        
        return []
    }
    
    static func updateToDoList() {
        
        //Grava a lista atual de ToDos
        let defaults = NSUserDefaults.standardUserDefaults()
        defaults.setObject(toDoList, forKey: TODO_LIST_KEY)
        defaults.synchronize()
        
        sendToDosToWatch()
    }
    
    static func crateNewToDo(title: String) {
        
        var toDoId:Int
        
        //Verifica se existe algum ToDo na lista e define o Id do proximo a ser inserido
        if(toDoList.count == 0) {
            toDoId = 1
        }
        else {
            toDoId = toDoList.reduce(Int.min) { max($0, $1[TODO_ID_KEY] as! Int) } + 1
        }
        
        toDoList.append([TODO_ID_KEY : toDoId,
            TODO_TITLE_KEY : title,
            TODO_DONE_KEY : false])
        
        ToDoController.updateToDoList()
    }
    
    static func deleteTodo(toDoItem: [String:AnyObject]) {
        
        if let idx  = toDoList.indexOf( { $0[TODO_ID_KEY] as! Int == toDoItem[TODO_ID_KEY] as! Int } ) {
            toDoList.removeAtIndex(idx)
        }
        
        ToDoController.updateToDoList()
    }
    
    static func toggleToDo(toDoId: Int) {
        
        if let idx  = toDoList.indexOf( { $0[TODO_ID_KEY] as! Int == toDoId } ) {
            toDoList[idx][TODO_DONE_KEY] = !(toDoList[idx][TODO_DONE_KEY] as! Bool)
        }
        
        ToDoController.updateToDoList()
    }
    
    static func sendToDosToWatch() {
        
        //Filtra os todos nao fimalizados
        let toDoUndone = toDoList.filter( {!($0[TODO_DONE_KEY] as! Bool)})
        let context:[String:AnyObject] = [TODO_LIST_KEY : toDoUndone]
        
        do {
            //envia os todos para o relogio
            try WCSession.defaultSession().updateApplicationContext(context)
        }
        catch {
            
        }
        
    }

}
