//
//  ToDoTableViewController.swift
//  ToDoWatch
//
//  Created by Andre M. Della Torre on 1/12/16.
//  Copyright © 2016 Andre M. Della Torre. All rights reserved.
//

import UIKit


class ToDoTableViewController: UITableViewController, WatchCommProtocol {

   let CELL_ID = "todocell"
    
    override func viewDidLoad() {
        super.viewDidLoad()

        let appDelegate = UIApplication.sharedApplication().delegate as! AppDelegate
        appDelegate.watchCommDelegate = self
    }

    override func viewWillAppear(animated: Bool) {

        super.viewWillAppear(animated)
        tableView.reloadData()
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
    }

    // MARK: - Table view data source

    override func numberOfSectionsInTableView(tableView: UITableView) -> Int {
        return 1
    }

    override func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return ToDoController.toDoList.count
    }

    override func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCellWithIdentifier(CELL_ID, forIndexPath: indexPath)

        // Configure the cell...
        let toDoItem = ToDoController.toDoList[indexPath.row]
        
        cell.textLabel!.text = (toDoItem[ToDoController.TODO_TITLE_KEY] as! String)
        
        cell.accessoryType = toDoItem[ToDoController.TODO_DONE_KEY] as! Bool ? UITableViewCellAccessoryType.Checkmark : UITableViewCellAccessoryType.None
        
        return cell
    }

    // Override to support editing the table view.
    override func tableView(tableView: UITableView, commitEditingStyle editingStyle: UITableViewCellEditingStyle, forRowAtIndexPath indexPath: NSIndexPath) {
        if editingStyle == .Delete {
            // Delete the row from the data source
            
            let toDoItem = ToDoController.toDoList[indexPath.row]
            
            ToDoController.deleteTodo(toDoItem)
            
            tableView.deleteRowsAtIndexPaths([indexPath], withRowAnimation: .Fade)
        }
    }
    
    override func tableView(tableView: UITableView, didSelectRowAtIndexPath indexPath: NSIndexPath) {
        tableView.deselectRowAtIndexPath(indexPath, animated: true)
        
        let toDoItem = ToDoController.toDoList[indexPath.row]
        ToDoController.toggleToDo(toDoItem[ToDoController.TODO_ID_KEY] as! Int)
        
        tableView.reloadData()
    }
    
    // Mark : WatchCommProtocol
    
    func itemToogled(ToDoId: Int) {
        ToDoController.toggleToDo(ToDoId)
        tableView.reloadData()
    }

}
